@@ -1,4 +1,4 @@
-from qplay_cli.user.user import User
+from qplay_cli.api_clients.user_api import UserAPIClient
 import click
 import getpass
 
@@ -27,7 +27,7 @@ def signup():
     response = User().confirm_signup(username, name, code)
     print(response['message'])
     
-    User().signin(username, p)
+    UserAPIClient().signin(username, p)
     
  
 @user.command() 
@@ -36,5 +36,5 @@ def signin():
     username = input()
     
     password = getpass.getpass()
-    User().signin(username, password)
+    UserAPIClient().signin(username, password)
     print("Sign in sucessfull")
\ No newline at end of file
